==> ejc-sale-impl-3.0.0-20220404.055637-20-sources.jar: com/ejianc/business/sale/vo/PaymentVO.java <==
package com.ejianc.business.sale.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.sale.vo.PaymentdetialVO;

/**
 * 付款管理
 * 
 * @author generator
 * 
 */
public class PaymentVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Long transportId; // 运输商主键
    private String transportName; // 运输商名称
    private String paymentAccount; // 付款账户
    private BigDecimal paymentMoney; // 付款金额
    private BigDecimal allicatedMoney; // 已付款金额
    private BigDecimal unallocatedMoney; // 未付款金额
    private Long paymentType; // 付款类型id
    private String paymentName; // 付款类型名称
    private String receiptCode; // 收据号
    private Date paymentTime; // 付款日期
    private Integer paymentStatus; // 付款状态
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private String abstracts; // 摘要
    
    private List<PaymentdetialVO> paymentdetialList = new ArrayList<>(); // 付款管理子表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getTransportId() {
        return transportId;
    }

    public void setTransportId(Long transportId) {
        this.transportId = transportId;
    }
    public String getTransportName() {
        return transportName;
    }

    public void setTransportName(String transportName) {
        this.transportName = transportName;
    }
    public String getPaymentAccount() {
        return paymentAccount;
    }

    public void setPaymentAccount(String paymentAccount) {
        this.paymentAccount = paymentAccount;
    }
    public BigDecimal getPaymentMoney() {
        return paymentMoney;
    }

    public void setPaymentMoney(BigDecimal paymentMoney) {
        this.paymentMoney = paymentMoney;
    }
    public BigDecimal getAllicatedMoney() {
        return allicatedMoney;
    }

    public void setAllicatedMoney(BigDecimal allicatedMoney) {
        this.allicatedMoney = allicatedMoney;
    }
    public BigDecimal getUnallocatedMoney() {
        return unallocatedMoney;
    }

    public void setUnallocatedMoney(BigDecimal unallocatedMoney) {
        this.unallocatedMoney = unallocatedMoney;
    }
    public Long getPaymentType() {
        return paymentType;
    }

    public void setPaymentType(Long paymentType) {
        this.paymentType = paymentType;
    }
    public String getPaymentName() {
        return paymentName;
    }

    public void setPaymentName(String paymentName) {
        this.paymentName = paymentName;
    }
    public String getReceiptCode() {
        return receiptCode;
    }

    public void setReceiptCode(String receiptCode) {
        this.receiptCode = receiptCode;
    }
    public Date getPaymentTime() {
        return paymentTime;
    }

    public void setPaymentTime(Date paymentTime) {
        this.paymentTime = paymentTime;
    }
    public Integer getPaymentStatus() {
        return paymentStatus;
    }

    public void setPaymentStatus(Integer paymentStatus) {
        this.paymentStatus = paymentStatus;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getAbstracts() {
        return abstracts;
    }

    public void setAbstracts(String abstracts) {
        this.abstracts = abstracts;
    }
    
     public List<PaymentdetialVO> getPaymentdetialList() {
        return paymentdetialList;
     }

     public void setPaymentdetialList(List<PaymentdetialVO> paymentdetialList) {
        this.paymentdetialList = paymentdetialList;
     }
}

==> ejc-sale-impl-3.0.0-20220513.022012-102-sources.jar: com/ejianc/business/sale/vo/PaymentVO.java <==
package com.ejianc.business.sale.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.sale.vo.PaymentdetialVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 付款管理
 * 
 * @author generator
 * 
 */
public class PaymentVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Long transportId; // 运输商主键
    private String transportName; // 运输商名称
    private String paymentAccount; // 付款账户
    private BigDecimal paymentMoney; // 付款金额
    private BigDecimal allicatedMoney; // 已付款金额
    private BigDecimal unallocatedMoney; // 未付款金额
    private Long paymentType; // 付款类型id
    private String paymentName; // 付款类型名称
    private String receiptCode; // 收据号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date paymentTime; // 付款日期
    private Integer paymentStatus; // 付款状态
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private String abstracts; // 摘要
    
    private List<PaymentdetialVO> paymentdetialList = new ArrayList<>(); // 付款管理子表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode="ShippersRef")
    public Long getTransportId() {
        return transportId;
    }
    @ReferDeserialTransfer
    public void setTransportId(Long transportId) {
        this.transportId = transportId;
    }
    public String getTransportName() {
        return transportName;
    }

    public void setTransportName(String transportName) {
        this.transportName = transportName;
    }
    public String getPaymentAccount() {
        return paymentAccount;
    }

    public void setPaymentAccount(String paymentAccount) {
        this.paymentAccount = paymentAccount;
    }
    public BigDecimal getPaymentMoney() {
        return paymentMoney;
    }

    public void setPaymentMoney(BigDecimal paymentMoney) {
        this.paymentMoney = paymentMoney;
    }
    public BigDecimal getAllicatedMoney() {
        return allicatedMoney;
    }

    public void setAllicatedMoney(BigDecimal allicatedMoney) {
        this.allicatedMoney = allicatedMoney;
    }
    public BigDecimal getUnallocatedMoney() {
        return unallocatedMoney;
    }

    public void setUnallocatedMoney(BigDecimal unallocatedMoney) {
        this.unallocatedMoney = unallocatedMoney;
    }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getPaymentType() {
        return paymentType;
    }
    @ReferDeserialTransfer
    public void setPaymentType(Long paymentType) {
        this.paymentType = paymentType;
    }
    public String getPaymentName() {
        return paymentName;
    }

    public void setPaymentName(String paymentName) {
        this.paymentName = paymentName;
    }
    public String getReceiptCode() {
        return receiptCode;
    }

    public void setReceiptCode(String receiptCode) {
        this.receiptCode = receiptCode;
    }
    public Date getPaymentTime() {
        return paymentTime;
    }

    public void setPaymentTime(Date paymentTime) {
        this.paymentTime = paymentTime;
    }
    public Integer getPaymentStatus() {
        return paymentStatus;
    }

    public void setPaymentStatus(Integer paymentStatus) {
        this.paymentStatus = paymentStatus;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getAbstracts() {
        return abstracts;
    }

    public void setAbstracts(String abstracts) {
        this.abstracts = abstracts;
    }
    
     public List<PaymentdetialVO> getPaymentdetialList() {
        return paymentdetialList;
     }

     public void setPaymentdetialList(List<PaymentdetialVO> paymentdetialList) {
        this.paymentdetialList = paymentdetialList;
     }
}
